@@ -48,10 +48,17 @@ class ReplaceableEntity:
         self.definition: str = definition.strip()
 
     @classmethod
-    def from_sql(cls: Type[T], sql: str) -> Optional[T]:
+    def from_sql(cls: Type[T], sql: str) -> T:
         """Create an instance from a SQL string"""
         raise NotImplementedError()
 
+    @classmethod
+    def from_path(cls: Type[T], path: Path) -> T:
+        """Create an instance instance from a SQL file path"""
+        with path.open() as sql_file:
+            sql = sql_file.read()
+        return cls.from_sql(sql)
+
     @classmethod
     def from_database(cls, connection, schema="%") -> List[T]:
         """Collect existing entities from the database for given schema"""
@@ -144,11 +151,11 @@ class ReplaceableEntity:
         """Render a string that is valid python code to reconstruct self in a migration"""
         var_name = self.to_variable_name()
         class_name = self.__class__.__name__
-        escaped_definition = self.definition.replace('"""', '\"\"\"') if not omit_definition else '# not required for op'
+        escaped_definition = self.definition if not omit_definition else "# not required for op"
         return f"""{var_name} = {class_name}(
             schema="{self.schema}",
             signature="{self.signature}",
-            definition=\"\"\"{escaped_definition}\"\"\"
+            definition={repr(escaped_definition)}
         )\n\n"""
 
     @classmethod
@@ -156,20 +163,13 @@ class ReplaceableEntity:
         """Render a string that is valid python code to import current class"""
         module_path = cls.__module__
         class_name = cls.__name__
-        return f"from {module_path} import {class_name}"
+        return f"from {module_path} import {class_name}\nfrom sqlalchemy import text as sql_text"
 
     @property
     def identity(self) -> str:
         """A string that consistently and globally identifies a function"""
         return f"{self.schema}.{self.signature}"
 
-    @classmethod
-    def from_path(cls: Type[T], path: Path) -> Optional[T]:
-        """Create an instance from a sql file path"""
-        with path.open() as sql_file:
-            sql = sql_file.read()
-        return cls.from_sql(sql)
-
     def to_variable_name(self):
         """A deterministic variable name based on PGFunction's contents """
         schema_name = self.schema.lower()
@@ -264,7 +264,9 @@ def render_drop_function(autogen_context, op):
     target = op.target
     autogen_context.imports.add(target.render_import_statement())
     variable_name = target.to_variable_name()
-    return target.render_self_for_migration(omit_definition=True) + f"op.drop_entity({variable_name})"
+    return (
+        target.render_self_for_migration(omit_definition=True) + f"op.drop_entity({variable_name})"
+    )
 
 
 @renderers.dispatch_for(ReplaceOp)
@@ -302,8 +304,15 @@ def register_entities(
     schemas: Optional[List[str]] = None,
     exclude_schemas: Optional[List[str]] = None,
 ) -> None:
-    """Creates an event listener to watch for changes in entities to populate migrations
-    when using --autogenerate"""
+    """Create an event listener to watch for changes in registered entities when migrations are created using
+    `alembic revision --autogenerate`
+
+    **Parameters:**
+
+    * **entities** - *List[ReplaceableEntity]*: A list of entities (PGFunction, PGView, etc) to monitor for revisions
+    * **schemas** - *Optional[List[str]]*: A list of SQL schema names to monitor. Note, schemas referenced in registered entities are automatically monitored.
+    * **exclude_schemas** - *Optional[List[str]]*: A list of SQL schemas to ignore. Note, explicitly registered entities will still be monitored.
+    """
 
     @comparators.dispatch_for("schema")
     def compare_registered_entities(
